==> jc-1.4.0.tar.gz: javax/swing/JPopupMenu__24Separator.h <==
// public class javax.swing.JPopupMenu$Separator

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class a6477de0b2bb9248 javax_swing_JPopupMenu__24Separator
// @dep_class 5b8de7320d210ab0 javax_swing_JSeparator

// header file dependencies
// @dep_header javax_swing_JSeparator

#include "javax/swing/JSeparator.h"

#ifndef _JC_javax_swing_JPopupMenu__24Separator_H_
#define _JC_javax_swing_JPopupMenu__24Separator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24Separator$sub_refs	_jc_javax_swing_JPopupMenu__24Separator$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24Separator$sub_nonrefs	_jc_javax_swing_JPopupMenu__24Separator$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24Separator$refs	_jc_javax_swing_JPopupMenu__24Separator$refs;
typedef struct _jc_javax_swing_JPopupMenu__24Separator$nonrefs	_jc_javax_swing_JPopupMenu__24Separator$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24Separator$object	_jc_javax_swing_JPopupMenu__24Separator$object;

typedef const struct _jc_javax_swing_JPopupMenu__24Separator$vmethods	_jc_javax_swing_JPopupMenu__24Separator$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24Separator$vtable	_jc_javax_swing_JPopupMenu__24Separator$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24Separator$vtype	_jc_javax_swing_JPopupMenu__24Separator$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24Separator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JPopupMenu__24Separator$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_JPopupMenu__24Separator$method$getUIClassID$ec5a776389969db1(_jc_env *, struct _jc_javax_swing_JPopupMenu__24Separator$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24Separator$method_info$getUIClassID$ec5a776389969db1;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24Separator$vmethods {
	struct _jc_java_lang_String$object	*(*getUIClassID$ec5a776389969db1)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24Separator$object *);
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24Separator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JSeparator$vmethods	javax_swing_JSeparator;
	_jc_javax_swing_JPopupMenu__24Separator$vmethods	javax_swing_JPopupMenu__24Separator;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24Separator$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24Separator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24Separator$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24Separator$refs {
    _jc_javax_swing_JPopupMenu__24Separator$sub_refs	javax_swing_JPopupMenu__24Separator;
    _jc_javax_swing_JSeparator$sub_refs	javax_swing_JSeparator;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24Separator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24Separator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JSeparator$sub_nonrefs	javax_swing_JSeparator;
    _jc_javax_swing_JPopupMenu__24Separator$sub_nonrefs	javax_swing_JPopupMenu__24Separator;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24Separator$object {
	_jc_javax_swing_JPopupMenu__24Separator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24Separator$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24Separator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24Separator$vtype _jc_javax_swing_JPopupMenu__24Separator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24Separator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24Separator$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24Separator_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JPopupMenu__24Separator.h <==
// public class javax.swing.JPopupMenu$Separator

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class a6477de0b2bb9248 javax_swing_JPopupMenu__24Separator
// @dep_class 5b8de7320d210ab0 javax_swing_JSeparator

// header file dependencies
// @dep_header javax_swing_JSeparator

#include "javax/swing/JSeparator.h"

#ifndef _JC_javax_swing_JPopupMenu__24Separator_H_
#define _JC_javax_swing_JPopupMenu__24Separator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24Separator$sub_refs	_jc_javax_swing_JPopupMenu__24Separator$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24Separator$sub_nonrefs	_jc_javax_swing_JPopupMenu__24Separator$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24Separator$refs	_jc_javax_swing_JPopupMenu__24Separator$refs;
typedef struct _jc_javax_swing_JPopupMenu__24Separator$nonrefs	_jc_javax_swing_JPopupMenu__24Separator$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24Separator$object	_jc_javax_swing_JPopupMenu__24Separator$object;

typedef const struct _jc_javax_swing_JPopupMenu__24Separator$vmethods	_jc_javax_swing_JPopupMenu__24Separator$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24Separator$vtable	_jc_javax_swing_JPopupMenu__24Separator$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24Separator$vtype	_jc_javax_swing_JPopupMenu__24Separator$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24Separator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JPopupMenu__24Separator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_JPopupMenu__24Separator$method$getUIClassID$ec5a776389969db1(_jc_env *, struct _jc_javax_swing_JPopupMenu__24Separator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24Separator$method_info$getUIClassID$ec5a776389969db1;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24Separator$vmethods {
	struct _jc_java_lang_String$object	*(*getUIClassID$ec5a776389969db1)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24Separator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24Separator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JSeparator$vmethods	javax_swing_JSeparator;
	_jc_javax_swing_JPopupMenu__24Separator$vmethods	javax_swing_JPopupMenu__24Separator;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24Separator$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24Separator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24Separator$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24Separator$refs {
    _jc_javax_swing_JPopupMenu__24Separator$sub_refs	javax_swing_JPopupMenu__24Separator;
    _jc_javax_swing_JSeparator$sub_refs	javax_swing_JSeparator;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24Separator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24Separator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JSeparator$sub_nonrefs	javax_swing_JSeparator;
    _jc_javax_swing_JPopupMenu__24Separator$sub_nonrefs	javax_swing_JPopupMenu__24Separator;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24Separator$object {
	_jc_javax_swing_JPopupMenu__24Separator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24Separator$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24Separator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24Separator$vtype _jc_javax_swing_JPopupMenu__24Separator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24Separator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24Separator$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24Separator_H_ */
